@@ -2,4 +2,4 @@
 Simple module to create and validate JWT tokens using
 Pydantic models and python-jose.
 """
-from jwt_pydantic.middleware import JWTPyantic, JWTPydanticMiddleware
+from jwt_pydantic.middleware import JWTPydantic, JWTPydanticMiddleware
